Documentation
¶
Index ¶
Constants ¶
const ( ChunkSize = 4096 RecordDelimitingLineCount = 2 )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CompressionType ¶
type CompressionType int
const ( // Compression Types NoCompression CompressionType = iota + 1 BzipCompression GzipCompression )
type Header ¶
Header represents a WARC named-field
func (Header) ContentLength ¶
ContentLength returns the content-length field-value
type Reader ¶
type Reader interface {
// Close closes the reader
Close() error
// Read reads up up to len(p) bytes into p
Read(p []byte) (n int, err error)
// Next returns the next WARC record in the archive
Next() (*Record, error)
// Seek sets the reader to the next record in the archive
Seek() error
// ReadLine reads the next line in the current record
ReadLine() (string, error)
}
Reader represents a WARC archive reader
Click to show internal directories.
Click to hide internal directories.